# Contributing

## Dev Environment

For a uniformat develepment environment lock files are a necessary.
For python using the same interpreter is important as well.
[uv](https://github.com/astral-sh/uv) fits this goal perfectly and thus is the preffered tool for 
the development environment.

```
uv run gamepadla
```


## Code Formatting

[ruff](https://github.com/astral-sh/ruff) should be used for formatting the code before it is pushed.

